package Perl::Examples;

our $DATE = '2018-09-10'; # DATE
our $VERSION = '0.090'; # VERSION

1;
# ABSTRACT: A collection of various examples of Perl modules/scripts

__END__

=pod

=encoding UTF-8

=head1 NAME

Perl::Examples - A collection of various examples of Perl modules/scripts

=head1 VERSION

This document describes version 0.090 of Perl::Examples (from Perl distribution Perl-Examples), released on 2018-09-10.

=head1 DESCRIPTION

B<EARLY RELEASE, MORE EXAMPLES TO COME, CONTRIBUTIONS WELCOME.>

This distribution, as the name suggests, contains a random collection of various
Perl modules/scripts, mostly for testing. Some examples are:

=over

=item * script that generates warning

=item * script that dies

=item * script that contains an endless loop

=item * script that grows indefinitely

=item * module that contains POD examples

=back

As more examples are added they might get reorganized (renamed, spun off to
another dist, etc).

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perl-Examples>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Perl-Examples>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perl-Examples>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018, 2016, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
